@@ -1,5 +1,5 @@
 package AI::Pathfinding::OptimizeMultiple::DataInputObj;
-$AI::Pathfinding::OptimizeMultiple::DataInputObj::VERSION = '0.0.16';
+$AI::Pathfinding::OptimizeMultiple::DataInputObj::VERSION = '0.0.17';
 use strict;
 use warnings;
 
@@ -14,8 +14,8 @@ use AI::Pathfinding::OptimizeMultiple::Scan ();
 use PDL              (qw( pdl ));
 use PDL::IO::FastRaw (qw( readfraw writefraw ));
 
-has start_board    => ( isa => 'Int', is => 'ro', required => 1 );
-has num_boards     => ( isa => 'Int', is => 'ro', required => 1 );
+has start_board => ( isa => 'Int', is => 'ro', required => 1 );
+has num_boards  => ( isa => 'Int', is => 'ro', required => 1 );
 has selected_scans => (
     isa      => 'ArrayRef',
     is       => 'ro',
@@ -447,7 +447,7 @@ AI::Pathfinding::OptimizeMultiple::DataInputObj - handle the data input.
 
 =head1 VERSION
 
-version 0.0.16
+version 0.0.17
 
 =head1 SUBROUTINES/METHODS
 
@@ -576,7 +576,7 @@ Shlomi Fish <shlomif@cpan.org>
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-L<https://github.com/shlomif/ai-pathfinding-optimizemultiple/issues>
+L<https://github.com/shlomif/fc-solve/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
