@@ -1,5 +1,5 @@
 package AI::Pathfinding::OptimizeMultiple::PostProcessor;
-$AI::Pathfinding::OptimizeMultiple::PostProcessor::VERSION = '0.0.16';
+$AI::Pathfinding::OptimizeMultiple::PostProcessor::VERSION = '0.0.17';
 use strict;
 use warnings;
 
@@ -9,8 +9,12 @@ use MooX qw/late/;
 
 has _should_do_rle =>
     ( isa => 'Bool', is => 'ro', init_arg => 'do_rle', required => 1 );
-has _offset_quotas =>
-    ( isa => 'Bool', is => 'ro', init_arg => 'offset_quotas', required => 1 );
+has _offset_quotas => (
+    isa      => 'Bool',
+    is       => 'ro',
+    init_arg => 'offset_quotas',
+    required => 1
+);
 
 sub scans_rle
 {
@@ -79,7 +83,7 @@ AI::Pathfinding::OptimizeMultiple::PostProcessor - post-processor.
 
 =head1 VERSION
 
-version 0.0.16
+version 0.0.17
 
 =head1 SUBROUTINES/METHODS
 
@@ -175,7 +179,7 @@ Shlomi Fish <shlomif@cpan.org>
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-L<https://github.com/shlomif/ai-pathfinding-optimizemultiple/issues>
+L<https://github.com/shlomif/fc-solve/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
